var model = function(model, jQuery) {
////// visible ///////////////////////////////////////////////////////////
    var visible = {};
    
    
    // pseudo constants //////////////////////////////////////////////////
    visible.ATTR_NAME = "__ATTR_NAME__";
    visible.ATTR_ROUTE = "__ATTR_ROUTE__";
    visible.ATTR_FREQUENCY = "__ATTR_FREQUENCY__";
    visible.ATTR_DOSE = "__ATTR_DOSE__";
    visible.ATTR_DRUG_CLASS = "__ATTR_DRUG_CLASS__";
    visible.ATTR_SUBITEM = "__ATTR_SUBITEM__";
    visible.ATTR_INSTRUCTIONS = "__ATTR_INSTRUCTIONS__";
    
    visible.ATTR_TYPE_NUMERIC = "__ATTR_TYPE_NUMERIC__";
    visible.ATTR_TYPE_GENERAL = "__ATTR_TYPE_GENERAL__";
    visible.ATTR_TYPE_CATEGORICAL = "__ATTR_TYPE_CATEGORICAL__";
    
    visible.DATASET_APP = "__DATASET_APPENDECTOMY__";
    visible.DATASET_CHF1 = "__DATASET_CONGESTIVE_HEART_FAILURE_1__";
    visible.DATASET_CHF2 = "__DATASET_CONGESTIVE_HEART_FAILURE_2__";
    visible.DATASET_PD1 = "__DATASET_PULMONARY_DISEASE_1__";
    visible.DATASET_PD2 = "__DATASET_PULMONARY_DISEASE_2__";
    visible.DATASET_OTHER_SIMPLE = "__DATASET_OTHER_SIMPLE__";
    visible.DATASET_OTHER_COMPLEX = "__DATASET_OTHER_COMPLEX__";
    visible.DATASET_DEFAULT = visible.DATASET_APP;
    
    visible.RECORDED_NAME = "recorded";
    visible.GENERIC_NAME = "generic";
    visible.BRAND_NAME = "brand";
    
    visible.AFTER_ACTION_GRAYOUT = "__AFTER_ACTION_GRAYOUT__";
    visible.AFTER_ACTION_REMOVE = "__AFTER_ACTION_REMOVE__";
    
    visible.FILTER_DELAY_SCALE = 4;
    
    
    // data //////////////////////////////////////////////////////////////
    visible.patientFirstName = "";
    visible.patientLastName = "";
    visible.patientAge = 0;
    visible.patientGender = "";
    
    visible.dataset = "";
    visible.items = {};
    
    visible.shadows = {};
    visible.itemsToShadows = {};
    visible.shadowsToItems = {};
    visible.hidden = {};
    
    visible.list1 = {
                id: "list0",
                name: "Intake",
                source: []
            };
    visible.list2 = {
                id: "list1",
                name: "Hospital",
                source: []
            };
    
	visible.getDatasetShortName = function(dataset) {
		switch(dataset) {
			case visible.DATASET_APP: return "APPNDCTMY";
    		case visible.DATASET_CHF1: return "CHF1";
    		case visible.DATASET_CHF2: return "CHF2";
    		case visible.DATASET_PD1: return "PD1"; 
			case visible.DATASET_PD2: return "PD2";
    		case visible.DATASET_OTHER_SIMPLE: return "O_SIMPLE";
    		case visible.DATASET_OTHER_COMPLEX: return "O_COMPLEX";
		}
		return undefined;
	};
	
	visible.getDatasetLongName = function(dataset) {
		switch(dataset) {
			case "APPNDCTMY": return visible.DATASET_APP;
    		case "CHF1": return visible.DATASET_CHF1;
    		case "CHF2": return visible.DATASET_CHF2;
    		case "PD1": return visible.DATASET_PD1; 
			case "PD2": return visible.DATASET_PD2;
    		case "O_SIMPLE": return visible.DATASET_OTHER_SIMPLE;
    		case "O_COMPLEX": return visible.DATASET_OTHER_COMPLEX;
		}
		return undefined;
	};
	 
    visible.viewData = function(sort, filter) {
        var viewData = visible.list1.source.concat(visible.list2.source);
        
        if (visible.multigroup && visible.groupBy) {
            for (var shadowID in visible.shadows) {
                var shadow = visible.shadows[shadowID];
                
                if (visible.groupBy in shadow.attributes &&
                        shadow.attributes[visible.groupBy].length > 1) {
                    viewData.push(shadowID);
                    
                    if (shadowID in visible.hidden) {
                        delete visible.hidden[shadowID];
                        controller.toggleItem($("#" + shadowID),
                                controller.toggleOnDelay, true);
                    }
                } else {
                    controller.toggleItem($("#" + shadowID),
                            controller.toggleOffDelay, false);
                    visible.hidden[shadowID] = true;
                }
            }
        } else {
            // no multigroup + groupBy = no shadows
            for (var shadowID in visible.shadows) {
                controller.toggleItem($("#" + shadowID),
                        controller.toggleOffDelay, false);
                visible.hidden[shadowID] = true;
            }
        }

        if (filter) {
            viewData = viewData.filter(unifiedFilter);
        }
        
        if (sort || filter) {
            viewData = viewData.sort(groupThenSort);
        }
        return viewData;
    }
    
    visible.attributes = {};

    visible.groupBy = "";
    visible.sortBy = visible.ATTR_NAME;
    visible.filterOn = "";
    visible.multigroup = false;
    
    visible.afterAction = visible.AFTER_ACTION_GRAYOUT;
    
    visible.unique1 = [];
    visible.unique2 = [];
    visible.identical = {};
    visible.similar = {};
    visible.nextID = 0;
    
    visible.accepted = [];      // arrays to preserve order of actions
    visible.rejected = [];
    visible.undecided = [];
    
    visible.displayName = visible.RECORDED_NAME;
    
    
    // methods ///////////////////////////////////////////////////////////
    visible.init = function(dataset) {
        resetState();
        loadData(dataset);
    };
    
    visible.decide = function(id, src, dst) {
        var index = visible[src].indexOf(parseFloat(id));
        
        if (index !== -1) {                     // shadows not included
            visible[src].splice(index, 1);
            visible[dst].push(parseFloat(id));
        }
    }
    
    visible.getIdentical = function(id, includeShadows) {
        var identical = [];
        var checkID = visible.items[id].isShadow ?
                visible.getShadowed(id) : id;
        
        if (checkID in visible.identical) {
            identical = visible.identical[checkID].slice();
        }
        identical.splice(identical.indexOf(parseFloat(checkID)), 1);
        
        if (includeShadows) {
            var shadows = [];
            
            for (var i = 0; i < identical.length; i++) {
                shadows =
                        shadows.concat(visible.getShadows(identical[i]));
            }
            identical = identical.concat(shadows);
        }
        return identical.filter(unifiedFilter);
    };
    
    visible.getSimilar = function(id, includeShadows) {
        var similar = [];
        var checkID = visible.items[id].isShadow ?
                visible.getShadowed(id) : id;
        
        if (checkID in visible.similar) {
            similar = visible.similar[checkID].items.slice();
        }
        similar.splice(similar.indexOf(parseFloat(checkID)), 1);

        if (includeShadows) {
            var shadows = [];
            
            for (var i = 0; i < similar.length; i++) {
                shadows = shadows.concat(visible.getShadows(similar[i]));
            }
            similar = similar.concat(shadows);
        }
        return similar.filter(unifiedFilter);
    };
    
    visible.getRelated = function(id, includeShadows) {
        var identical = visible.getIdentical(id, includeShadows);
        var similar = visible.getSimilar(id, includeShadows);
        var hash = {};
        var length = Math.min(identical.length, similar.length);
        
        // remove duplicates
        for (var i = 0; i < length; i++) {
            hash[identical[i]] = true;
            hash[similar[i]] = true;
        }
        
        if (length < identical.length) {
            for ( ; i < identical.length; i++) {
                hash[identical[i]] = true;
            }
        } else if (length < similar.length) {
            for ( ; i < similar.length; i++) {
                hash[similar[i]] = true;
            }
        }
        
        // convert results into array format
        var related = [];
        
        for (var hashedID in hash) {
            related.push(hashedID);
        }
        return related;
    };
    
    visible.getIdenticalSet = function(id, includeShadows) {
        return visible.getShadowSet(id)
                .concat(visible.getIdentical(id, includeShadows));
    };
    
    visible.getSimilarSet = function(id, includeShadows) {
        return visible.getShadowSet(id)
                .concat(visible.getSimilar(id, includeShadows));
    }
    
    visible.getRelatedSet = function(id, includeShadows) {
        return visible.getShadowSet(id)
                .concat(visible.getRelated(id, includeShadows));
    };
    
    visible.getShadows = function(id) {
        if (id in visible.itemsToShadows) {
            return visible.itemsToShadows[id];
        }
        return [];
    };
    
    visible.getShadowed = function(id) {
        return visible.shadowsToItems[id];
    };
    
    visible.getShadowSet = function(id) {
        var checkID = visible.items[id].isShadow ?
                visible.getShadowed(id) : id;
        
        return [checkID].concat(visible.getShadows(checkID));
    };
    
    
////// hidden ////////////////////////////////////////////////////////////

    // initialization
    function resetState() {
        visible.items = {};
        visible.list1.source = [];
        visible.list2.source = [];
        
        visible.shadows = {};
        visible.itemsToShadows = {};
        visible.shadowsToItems = {};
        visible.hidden = {};
        
        visible.attributes = {};
    
        visible.unique1 = [];
        visible.unique2 = [];
        visible.identical = {};
        visible.similar = {};
        visible.nextID = 0;
        
        visible.accepted = [];
        visible.rejected = [];
        visible.undecided = [];
    }
    
    function loadData(dataset) {
        visible.dataset = dataset;
        populateLists(dataset);
        detectAttributes();
        detectRelationships(dataset);
        
        // create "shadows", copies, to show n-group affiliation
        populateShadows();
    }
    
    function populateLists(dataset) {
        var i = 0, name = {}, attributes = {}, item = {};
        
        if (dataset === visible.DATASET_APP) {
        	// arbitrary popular patient name TODO randomize?
        	visible.patientFirstName = "David"; 
        	visible.patientLastName = "Doe";
        	visible.patientAge = 55;
    		visible.patientGender = "M";
    		
            //populate list 1
            name = {
                recorded: "aspirin",
                generic: "aspirin",
                brand: "Bayer"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["81 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] =
                    ["non-steroidal anti-inflammatory drug",
                    "analgesic", "antiplatelet", "antipyretic"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Chantix",
                generic: "varenicline",
                brand: "Chantix"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["81 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] = ["antismoking"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Lipitor",
                generic: "atorvastatin",
                brand: "Lipitor"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["20 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] = ["anticholesterol"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Capoten",
                generic: "captopril",
                brand: "Capoten"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["25 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["BID"];
            attributes[visible.ATTR_DRUG_CLASS] = ["antihypertensive"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "multivitamin",
                generic: "multivitamin",
                brand: "multivitamin"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["1 tablet"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] = ["dietary supplement"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Sonata",
                generic: "zaleplon",
                brand: "Sonata"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["10 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["qHS prn"];
            attributes[visible.ATTR_DRUG_CLASS] = ["sedative"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            // populate list 2
            name = {
                recorded: "captopril",
                generic: "captopril",
                brand: "Capoten"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["25 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["BID"];
            attributes[visible.ATTR_DRUG_CLASS] = ["antihypertensive"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "atorvastatin",
                generic: "atorvastatin",
                brand: "Lipitor"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["25 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["qAM"];
            attributes[visible.ATTR_DRUG_CLASS] = ["anticholesterol"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "multivitamin",
                generic: "multivitamin",
                brand: "multivitamin"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["1 tablet"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] = ["dietary supplement"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "temazepam",
                generic: "temazepam",
                brand: "Restoril"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["15 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["qHS"];
            attributes[visible.ATTR_DRUG_CLASS] =
                    ["sedative", "antianxiety"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "tramadol",
                generic: "tramadol",
                brand: "Ultram"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["50 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["q4h prn pain"];
            attributes[visible.ATTR_DRUG_CLASS] = ["analgesic"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Chantix",
                generic: "varenicline",
                brand: "Chantix"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["81 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] = ["antismoking"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
        } else if (dataset === visible.DATASET_CHF1) {
        	// arbitrary popular patient name TODO randomize?
        	visible.patientFirstName = "Jim";
        	visible.patientLastName = "Jones";
			visible.patientAge = 74;
    		visible.patientGender = "M";
    		
            // populate list 1
            name = {
                recorded: "acetaminophen",
                generic: "acetaminophen",
                brand: "Tylenol"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["650 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["q4h prn"];
            attributes[visible.ATTR_DRUG_CLASS] =
                    ["analgesic", "antipyretic"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Aldactone",
                generic: "spironolactone",
                brand: "Aldactone"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["100 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] = ["antihypertensive"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Amaryl",
                generic: "glimepiride",
                brand: "Amaryl"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["4 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] = ["antidiabetic"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Ambien",
                generic: "zolpidem",
                brand: "Ambien"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["10 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["qHS prn"];
            attributes[visible.ATTR_DRUG_CLASS] = ["sedative"];
            
            item = new ListItem (i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Aricept",
                generic: "donepezil",
                brand: "Aricept"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["10 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] =
                    ["acetylcholinesterase inhibitor"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            

            name = {
                recorded: "aspirin",
                generic: "aspirin",
                brand: "Bayer"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["81 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] =
                    ["non-steroidal anti-inflammatory drug",
                    "analgesic", "antiplatelet", "antipyretic"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "cimetidine",
                generic: "cimetidine",
                brand: "Tagamet"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["800 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["BID"];
            attributes[visible.ATTR_DRUG_CLASS] = ["antacid"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Coreg",
                generic: "carvedilol",
                brand: "Coreg"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["6.25 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["BID"];
            attributes[visible.ATTR_DRUG_CLASS] = ["antihypertensive"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Colace",
                generic: "ducosate",
                brand: "Colace"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["100 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["BID"];
            attributes[visible.ATTR_DRUG_CLASS] = ["stool softener"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            
            name = {
                recorded: "Crestor",
                generic: "rosuvastatin",
                brand: "Crestor"
            }
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["20 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] = ["anticholesterol"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Hyzaar",
                generic: "losartan + hydrochlorothiazide",
                brand: "Hyzaar"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["100 / 25 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] = ["antihypertensive",
                    "diuretic"];
            attributes[visible.ATTR_SUBITEM] = [
                        {
                            name: "losartan",
                            attributes: { "__ATTR_DOSE__" : "100 mg" }
                        },
                        {
                            name: "hydrochlorothiazide",
                            attributes: { "__ATTR_DOSE__" : "25 mg" }
                        }
                    ];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            // populate list 2
            name = {
                recorded: "acetaminophen",
                generic: "acetaminophen",
                brand: "Tylenol"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["650 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] =
                    ["q4h prn headache or pain"];
            attributes[visible.ATTR_DRUG_CLASS] =
                    ["analgesic", "antipyretic"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "aspirin",
                generic: "aspirin",
                brand: "Bayer"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["81 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] =
                    ["non-steroidal anti-inflammatory drug",
                    "analgesic", "antiplatelet", "antipyretic"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Coreg",
                generic: "carvedilol",
                brand: "Coreg"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["6.25 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["BID"];
            attributes[visible.ATTR_DRUG_CLASS] = ["antihypertensive"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "cimetidine",
                generic: "cimetidine",
                brand: "Tagamet"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["800 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["q12h"];
            attributes[visible.ATTR_DRUG_CLASS] = ["antacid"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "donepezil",
                generic: "donepezil",
                brand: "Aricept"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["10 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["qAM"];
            attributes[visible.ATTR_DRUG_CLASS] =
                    ["acetylcholinesterase inhibitor"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "furosemide",
                generic: "furosemide",
                brand: "Lasix"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["40 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["BID"];
            attributes[visible.ATTR_DRUG_CLASS] =
                    ["diuretic", "antihypertensive"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "glimepiride",
                generic: "glimepiride",
                brand: "Amaryl"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["4 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["qAM"];
            attributes[visible.ATTR_DRUG_CLASS] = ["antidiabetic"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "lorazepam",
                generic: "lorazepam",
                brand: "Ativan"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["1 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["qHS prn insomnia"];
            attributes[visible.ATTR_DRUG_CLASS] =
                    ["sedative", "antianxiety"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "losartan",
                generic: "losartan",
                brand: "Cozaar"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["50 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["qAM"];
            attributes[visible.ATTR_DRUG_CLASS] =
                    ["antihypertensive"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "magnesium hydroxide",
                generic: "magnesium hydroxide",
                brand: "Milk of magnesia"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["30 ml"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily prn constipation"];
            attributes[visible.ATTR_DRUG_CLASS] =
                    ["laxative", "antacid"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "rosuvastatin",
                generic: "rosuvastatin",
                brand: "Crestor"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["20 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["qAM"];
            attributes[visible.ATTR_DRUG_CLASS] = ["anticholesterol"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "spironolactone",
                generic: "spironolactone",
                brand: "Aldactone"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["100 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["qAM"];
            attributes[visible.ATTR_DRUG_CLASS] = ["antihypertensive"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
        } else if (dataset === visible.DATASET_CHF2) {
        	// arbitrary popular patient name TODO randomize?
        	visible.patientFirstName = "Mary";
        	visible.patientLastName = "Smith";
        	visible.patientAge = 65;
    		visible.patientGender = "F";
    		
            // populate list 1
            name = {
                recorded: "Coreg",
                generic: "carvedilol",
                brand: "Coreg"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["25 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["BID"];
            attributes[visible.ATTR_DRUG_CLASS] =
                    ["antihypertensive"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "HCTZ",
                generic: "hydrochlorothiazide",
                brand: "Hydrodiuril"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["25 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] =
                    ["diuretic", "antihypertensive"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Coumadin",
                generic: "warfarin",
                brand: "Coumadin"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["5 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] =
                    ["anticoagulant"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Lasix",
                generic: "furosemide",
                brand: "Lasix"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["40 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] =
                    ["diuretic", "antihypertensive"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Percocet",
                generic: "acetaminophen + oxycodone",
                brand: "Percocet"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["1 tablet"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["q4h prn pain"];
            attributes[visible.ATTR_DRUG_CLASS] = ["analgesic"];
            attributes[visible.ATTR_SUBITEM] = [
                        {
                            name: "acetaminophen",
                            attributes: { "__ATTR_DOSE__" : "" }
                        },
                        {
                            name: "oxycodone",
                            attributes: { "__ATTR_DOSE__" : "" }
                        }
                    ];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Zantac",
                generic: "ranitidine",
                brand: "Zantac"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["150 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["BID"];
            attributes[visible.ATTR_DRUG_CLASS] =
                    ["antacid"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Dulcolax",
                generic: "bisacodyl",
                brand: "Dulcolax"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["10 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily prn"];
            attributes[visible.ATTR_DRUG_CLASS] = ["laxative"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "loratadine",
                generic: "loratadine",
                brand: "Claritin"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["10 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily prn"];
            attributes[visible.ATTR_DRUG_CLASS] = ["antihistamine"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Metamucil",
                generic: "psyllium husk",
                brand: "Metamucil"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["1 tbsp"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] = ["stool softener"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
                        
            
            name = {
                recorded: "pravastatin",
                generic: "pravastatin",
                brand: "Pravachol"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["40 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] = ["anticholesterol"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "zaleplon",
                generic: "zaleplon",
                brand: "Sonata"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["10 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["qHS prn"];
            attributes[visible.ATTR_DRUG_CLASS] = ["sedative"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;

            
            // populate list 2
            name = {
                recorded: "carvedilol",
                generic: "carvedilol",
                brand: "Coreg"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["25 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["BID"];
            attributes[visible.ATTR_DRUG_CLASS] =
                    ["antihypertensive"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "hydrochlorothiazide",
                generic: "hydrochlorothiazide",
                brand: "Hydrodiuril"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["50 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] =
                    ["diuretic", "antihypertensive"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "warfarin",
                generic: "warfarin",
                brand: "Coumadin"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["4 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] =
                    ["anticoagulant"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "magnesium hydroxide",
                generic: "magnesium hydroxide",
                brand: "Milk of Magnesia"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["30 ml"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] =
                    ["daily prn constipation"];
            attributes[visible.ATTR_DRUG_CLASS] = ["laxative", "antacid"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "loratadine",
                generic: "loratadine",
                brand: "Claritin"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["10 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily prn"];
            attributes[visible.ATTR_DRUG_CLASS] = ["antihistamine"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "pravastatin",
                generic: "pravastatin",
                brand: "Pravachol"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["40 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] = ["anticholesterol"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "zaleplon",
                generic: "zaleplon",
                brand: "Sonata"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["10 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["qHS prn insomnia"];
            attributes[visible.ATTR_DRUG_CLASS] = ["sedative"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "furosemide",
                generic: "furosemide",
                brand: "Lasix"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["40 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["BID"];
            attributes[visible.ATTR_DRUG_CLASS] =
                    ["diuretic", "antihypertensive"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "oxycodone",
                generic: "oxycodone",
                brand: "Oxycontin"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["5 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["q4-6h prn pain"];
            attributes[visible.ATTR_DRUG_CLASS] =
                    ["analgesic"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "acetaminophen",
                generic: "acetaminophen",
                brand: "Tylenol"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["650 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["q4h prn pain"];
            attributes[visible.ATTR_DRUG_CLASS] =
                    ["analgesic"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "pantoprazole",
                generic: "pantoprazole",
                brand: "Protonix"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["20 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["BID"];
            attributes[visible.ATTR_DRUG_CLASS] =
                    ["antacid"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
        } else if (dataset === visible.DATASET_PD1) {
        	// arbitrary popular patient name TODO randomize?
        	visible.patientFirstName = "Penny";
        	visible.patientLastName = "Pfeifer";
        	visible.patientAge = 63;
		    visible.patientGender = "F";
    
            // populate list 1
            name = {
                recorded: "Abilify",
                generic: "aripiprazole",
                brand: "Abilify"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["5 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] =
                    ["antipsychotic", "antidepressant"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Advair",
                generic: "salmeterol + fluticasone",
                brand: "Advair"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["250 / 50 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["BID"];
            attributes[visible.ATTR_DRUG_CLASS] = ["bronchodilator"];
            attributes[visible.ATTR_SUBITEM] = [
                        {
                            name: "salmeterol",
                            attributes: { "__ATTR_DOSE__" : "250 mg" }
                        },
                        {
                            name: "fluticasone",
                            attributes: { "__ATTR_DOSE__" : "50 mg" }
                        }
                    ];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Bactrim",
                generic: "trimethoprim + sulfamethoxazole",
                brand: "Bactrim"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["2 tablets"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["q12h"];
            attributes[visible.ATTR_DRUG_CLASS] = ["antibiotic"];
            attributes[visible.ATTR_SUBITEM] = [
                        {
                            name: "trimethoprim",
                            attributes: { "__ATTR_DOSE__" : "" }
                        },
                        {
                            name: "sulfamethoxazole",
                            attributes: { "__ATTR_DOSE__" : "" }
                        }
                    ];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "multivitamin",
                generic: "multivitamin",
                brand: "multivitamin"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["1 tablet"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] = ["dietary supplement"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Fosamax+D",
                generic: "alendronate + vitamin D",
                brand: "Fosamax+D"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["1 tablet"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] =
                    ["bone resorption inhibitor"];
             attributes[visible.ATTR_SUBITEM] = [
                        {
                            name: "alendronate",
                            attributes: { "__ATTR_DOSE__" : "" }
                        },
                        {
                            name: "vitamin D",
                            attributes: { "__ATTR_DOSE__" : "" }
                        }
                    ];
           
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Hygroton",
                generic: "chlorthalidone",
                brand: "Hygroton"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["50 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] =
                    ["diuretic", "antihypertensive"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Lunesta",
                generic: "eszopiclone",
                brand: "Lunesta"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["2 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["qHS prn"];
            attributes[visible.ATTR_DRUG_CLASS] = ["sedative"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Plavix",
                generic: "clopidogrel",
                brand: "Plavix"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["75 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] = ["antiplatelet"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "prednisone",
                generic: "prednisone",
                brand: "Deltasone"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["40 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["taper"];
            attributes[visible.ATTR_DRUG_CLASS] = ["corticosteroid"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Premarin",
                generic: "conjugated estrogens",
                brand: "Premarin"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["0.3 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] = ["sex hormone"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Metamucil",
                generic: "psyllium husk",
                brand: "Metamucil"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["1 tbsp"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] = ["stool softener"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Nexium",
                generic: "esomeprazole",
                brand: "Nexium"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["20 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] = ["antacid"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Senokot",
                generic: "sennosides",
                brand: "Senokot"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["2 tablets"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] =
                    ["daily prn constipation"];
            attributes[visible.ATTR_DRUG_CLASS] = ["laxative"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "vitamin D",
                generic: "vitamin D",
                brand: "Calciferol"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["800 IU"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] = ["dietary supplement"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Zestril",
                generic: "lisinopril",
                brand: "Zestril"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["20 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] = ["antihypertensive"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "bupropion",
                generic: "bupropion",
                brand: "Zyban"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["150 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["BID"];
            attributes[visible.ATTR_DRUG_CLASS] =
                    ["antidepressant", "antismoking"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            // populate list 2
            name = {
                recorded: "acetaminophen",
                generic: "acetaminophen",
                brand: "Tylenol"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["650 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["q4h prn headache"];
            attributes[visible.ATTR_DRUG_CLASS] =
                    ["analgesic", "antipyretic"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "alendronate",
                generic: "alendronate",
                brand: "Fosamax"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["10 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] =
                    ["bone resorption inhibitor"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "bupropion",
                generic: "bupropion",
                brand: "Zyban"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["150 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["BID"];
            attributes[visible.ATTR_DRUG_CLASS] =
                    ["antidepressant", "antismoking"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "moxifloxacin",
                generic: "moxifloxacin",
                brand: "Avelox"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["400 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] = ["antibiotic"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "clopidogrel",
                generic: "clopidogrel",
                brand: "Plavix"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["75 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["qAM"];
            attributes[visible.ATTR_DRUG_CLASS] = ["antiplatelet"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "conjugated estrogens",
                generic: "conjugated estrogens",
                brand: "Premarin"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["0.3 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["qAM"];
            attributes[visible.ATTR_DRUG_CLASS] = ["sex hormone"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "hydrochlorthiazide",
                generic: "hydrochlorthiazide",
                brand: "Hydrodiuril"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["50 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["qAM"];
            attributes[visible.ATTR_DRUG_CLASS] =
                    ["diuretic", "antihypertensive"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "lorazepam",
                generic: "lorazepam",
                brand: "Ativan"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["0.5 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["qHS prn"];
            attributes[visible.ATTR_DRUG_CLASS] =
                    ["sedative", "antianxiety"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "prednisone",
                generic: "prednisone",
                brand: "Deltasone"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["30 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["taper"];
            attributes[visible.ATTR_DRUG_CLASS] = ["corticosteroid"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "magnesium hydroxide",
                generic: "magnesium hydroxide",
                brand: "Milk of Magnesia"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["30 ml"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] =
                    ["daily prn constipation"];
            attributes[visible.ATTR_DRUG_CLASS] = ["laxative", "antacid"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "multivitamin",
                generic: "multivitamin",
                brand: "multivitamin"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["1 tablet"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] = ["dietary supplement"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "pantoprazole",
                generic: "pantoprazole",
                brand: "Protonix"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["40 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["qAM"];
            attributes[visible.ATTR_DRUG_CLASS] = ["antacid"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "salmeterol + fluticasone",
                generic: "salmeterol + fluticasone",
                brand: "Advair"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["250 / 50 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["BID"];
            attributes[visible.ATTR_DRUG_CLASS] = ["bronchodilator"];
            attributes[visible.ATTR_SUBITEM] = [
                        {
                            name: "salmeterol",
                            attributes: { "__ATTR_DOSE__" : "250 mg" }
                        },
                        {
                            name: "fluticasone",
                            attributes: { "__ATTR_DOSE__" : "50 mg" }
                        }
                    ];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
        } else if (dataset === visible.DATASET_PD2) {
        	// arbitrary popular patient name TODO randomize?
        	visible.patientFirstName = "Richard";
        	visible.patientLastName = "White";
        	visible.patientAge = 80;
    		visible.patientGender = "M";
    		
            // populate list 1
            name = {
                recorded: "dabigatran",
                generic: "dabigatran",
                brand: "Pradaxa"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["150 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["BID"];
            attributes[visible.ATTR_DRUG_CLASS] = ["anticoagulant"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Zestoretic",
                generic: "hydrochlorothiazide + lisinopril",
                brand: "Zestoretic"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["20 / 12.5 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] =
                    ["antihypertensive", "diuretic"];
            attributes[visible.ATTR_SUBITEM] = [
                        {
                            name: "hydrochlorothiazide",
                            attributes: { "__ATTR_DOSE__" : "20 mg" }
                        },
                        {
                            name: "lisinopril",
                            attributes: { "__ATTR_DOSE__" : "12.5 mg" }
                        }
                    ];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "metformin",
                generic: "metformin",
                brand: "Glucophage"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["850 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] = ["antidiabetic"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Micronase",
                generic: "glyburide",
                brand: "glyburide"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["5 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] = ["antidiabetic"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Toprol XL",
                generic: "metoprolol",
                brand: "Toprol XL"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["25 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] = ["antihypertensive"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "acetaminophen",
                generic: "acetaminophen",
                brand: "Tylenol"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["1 g"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["q6h prn pain"];
            attributes[visible.ATTR_DRUG_CLASS] =
                    ["analgesic", "antipyretic"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "tramadol",
                generic: "tramadol",
                brand: "Ultram"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["50 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["q6h prn pain"];
            attributes[visible.ATTR_DRUG_CLASS] = ["analgesic"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Plavix",
                generic: "clopidogrel",
                brand: "Plavix"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["75 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] = ["antiplatelet"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Aricept",
                generic: "donepezil",
                brand: "Aricept"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["10 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] =
                    ["acetylcholinesterase inhibitor"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Prozac",
                generic: "fluoxetine",
                brand: "Prozac"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["20 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] = ["antidepressant"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "vitamin B12",
                generic: "vitamin B12",
                brand: "vitamin B12"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["1000 mcg"];
            attributes[visible.ATTR_ROUTE] = ["SC"];
            attributes[visible.ATTR_FREQUENCY] = ["qMonth"];
            attributes[visible.ATTR_DRUG_CLASS] = ["dietary supplement"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Calciferol",
                generic: "vitamin D",
                brand: "Calciferol"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["600 IU"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] = ["dietary supplement"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "calcium carbonate",
                generic: "calcium carbonate",
                brand: "Tums"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["500 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["QID"];
            attributes[visible.ATTR_DRUG_CLASS] = ["dietary supplement"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "lorazepam",
                generic: "lorazepam",
                brand: "Ativan"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["1 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["q8h prn anxiety"];
            attributes[visible.ATTR_DRUG_CLASS] =
                    ["sedative", "antianxiety"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Lipitor",
                generic: "rosuvastatin",
                brand: "Lipitor"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["40 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] = ["anticholesterol"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Tirosint",
                generic: "levothyroxine",
                brand: "Tirosint"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["100 mcg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] = ["thyroid"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            // populate list 2
            name = {
                recorded: "enoxaparin",
                generic: "enoxaparin",
                brand: "Lovenox"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["40 mg"];
            attributes[visible.ATTR_ROUTE] = ["SC"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] =
                    ["anticoagulant"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "lisinopril",
                generic: "lisinopril",
                brand: "Zestril"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["20 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] = ["antihypertensive"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "hydrochlorothiazide",
                generic: "hydrochlorothiazide",
                brand: "Hydrodiuril"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["12.5 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] =
                    ["diuretic", "antihypertensive"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "insulin sliding scale",
                generic: "insulin sliding scale",
                brand: "Humulin"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = [""];
            attributes[visible.ATTR_ROUTE] = ["SC"];
            attributes[visible.ATTR_FREQUENCY] = ["q4h prn"];
            attributes[visible.ATTR_DRUG_CLASS] = ["antidiabetic"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Lantus",
                generic: "insulin glargine",
                brand: "Lantus"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["20 mg"];
            attributes[visible.ATTR_ROUTE] = ["SC"];
            attributes[visible.ATTR_FREQUENCY] = ["qHS"];
            attributes[visible.ATTR_DRUG_CLASS] = ["antidiabetic"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "metoprolol",
                generic: "metoprolol",
                brand: "Toprol XL"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["50 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["BID"];
            attributes[visible.ATTR_DRUG_CLASS] = ["antihypertensive"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "acetaminophen",
                generic: "acetaminophen",
                brand: "Tylenol"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["1 g"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["q6h prn pain"];
            attributes[visible.ATTR_DRUG_CLASS] =
                    ["analgesic", "antipyretic"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "tramadol",
                generic: "tramadol",
                brand: "Ultram"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["50 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["q6h prn pain"];
            attributes[visible.ATTR_DRUG_CLASS] = ["analgesic"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "clopidogrel",
                generic: "clopidogrel",
                brand: "Plavix"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["75 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] = ["antiplatelet"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "donepezil",
                generic: "donepezil",
                brand: "Aricept"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["10 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["qHS"];
            attributes[visible.ATTR_DRUG_CLASS] =
                    ["acetylcholinesterase inhibitor"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "fluoxetine",
                generic: "fluoxetine",
                brand: "Prozac"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["20 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] = ["antidepressant"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "lorazepam",
                generic: "lorazepam",
                brand: "Ativan"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["1 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["q8h prn anxiety"];
            attributes[visible.ATTR_DRUG_CLASS] =
                    ["sedative", "antianxiety"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "rosuvastatin",
                generic: "rosuvastatin",
                brand: "Lipitor"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["40 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DRUG_CLASS] = ["anticholesterol"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "cephalexin",
                generic: "cephalexin",
                brand: "Biocef"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["500 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["q6h"];
            attributes[visible.ATTR_DRUG_CLASS] = ["antibiotic"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
        } else if (dataset === visible.DATASET_OTHER_SIMPLE) {
        	
        	// arbitrary popular patient name TODO randomize?
        	visible.patientFirstName = "John";
        	visible.patientLastName = "Doe";
        	visible.patientAge = 30;
    		visible.patientGender = "M";
    		
        	// populate list 1
        	name = {
                recorded: "Acetaminophen",
                generic: "Acetaminophen",
                brand: "Acetaminophen"
            };
            
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["325 mg"];
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["q6h"];
            attributes[visible.ATTR_DRUG_CLASS] = ["analgesic", "antipyretic"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Darbepoetin",
                generic: "Darbepoetin",
                brand: "Darbepoetin"
            };
            attributes = {};
            attributes[visible.ATTR_DOSE] = ["60 mg"];
            attributes[visible.ATTR_ROUTE] = ["SC"];
            attributes[visible.ATTR_FREQUENCY] = ["qFriday"];
            attributes[visible.ATTR_DRUG_CLASS] = ["ESA"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Calcitrol",
                generic: "Calcitrol",
                brand: "Calcitrol"
            };
            attributes = {};
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DOSE] = ["0.25 mg"];
            attributes[visible.ATTR_DRUG_CLASS] = ["supplement"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Ramipril",
                generic: "Ramipril",
                brand: "Ramipril"
            };
            attributes = {};
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DOSE] = ["5 mg"];
            attributes[visible.ATTR_DRUG_CLASS] = ["ACE inhibitor"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Meloxicam",
                generic: "Meloxicam",
                brand: "Meloxicam"
            };
            attributes = {};
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DOSE] = ["7.5 mg"];
            attributes[visible.ATTR_DRUG_CLASS] = ["analgesic", "NSAID"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Folvite",
                generic: "Folvite",
                brand: "Folvite"
            };
            attributes = {};
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DOSE] = ["1 mg"];
            attributes[visible.ATTR_DRUG_CLASS] = ["supplement"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            // populate list 2
            name = {
                recorded: "Acetaminophen",
                generic: "Acetaminophen",
                brand: "Acetaminophen"
            };
            attributes = {};
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["q4h"];
            attributes[visible.ATTR_DOSE] = ["325 mg"];
            attributes[visible.ATTR_DRUG_CLASS] = ["analgesic", "antipyretic"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Darbepoetin",
                generic: "Darbepoetin",
                brand: "Darbepoetin"
            };
            attributes = {};
            attributes[visible.ATTR_ROUTE] = ["SC"];
            attributes[visible.ATTR_FREQUENCY] = ["qFriday"];
            attributes[visible.ATTR_DOSE] = ["60 mg"];
            attributes[visible.ATTR_DRUG_CLASS] = ["ESA"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Folic acid",
                generic: "Folic acid",
                brand: "Folic acid"
            };
            attributes = {};
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DOSE] = ["1 mg"];
            attributes[visible.ATTR_DRUG_CLASS] = ["supplement"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Omeprazole",
                generic: "Omeprazole",
                brand: "Omeprazole"
            };
            attributes = {};
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DOSE] = ["40 mg"];
            attributes[visible.ATTR_DRUG_CLASS] = ["proton-pump inhibitor"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Ciprofloxacin",
                generic: "Ciprofloxacin",
                brand: "Ciprofloxacin"
            };
            attributes = {};
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DOSE] = ["500 mg"];
            attributes[visible.ATTR_DRUG_CLASS] = ["antibiotic"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Ramipril",
                generic: "Ramipril",
                brand: "Ramipril"
            };
            attributes = {};
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DOSE] = ["5 mg"];
            attributes[visible.ATTR_DRUG_CLASS] = ["ACE inhibitor"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Calcitrol",
                generic: "Calcitrol",
                brand: "Calcitrol"
            };
            attributes = {};
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DOSE] = ["0.25 mg"];
            attributes[visible.ATTR_DRUG_CLASS] = ["supplement"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Ferrous Gloconate",
                generic: "Ferrous Gloconate",
                brand: "Ferrous Gloconate"
            };
            attributes = {};
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["TID"];
            attributes[visible.ATTR_DOSE] = ["300 mg"];
            attributes[visible.ATTR_DRUG_CLASS] = ["supplement"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
        } else if (dataset === visible.DATASET_OTHER_COMPLEX) {
        	// arbitrary popular patient name TODO randomize?
        	visible.patientFirstName = "Jane";
        	visible.patientLastName = "Doe";
        	visible.patientAge = 30;
    		visible.patientGender = "F";
    		
        	// populate list 1
        	name = {
                recorded: "Acetaminophen",
                generic: "Acetaminophen",
                brand: "Acetaminophen"
            };
            attributes = {};
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["q4h"];
            attributes[visible.ATTR_DOSE] = ["325 mg"];
            attributes[visible.ATTR_DRUG_CLASS] = ["analgesic", "antipyretic"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Tylenol",
                generic: "Tylenol",
                brand: "Tylenol"
            };
            attributes = {};
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["q6h"];
            attributes[visible.ATTR_DOSE] = ["325 mg"];
            attributes[visible.ATTR_DRUG_CLASS] = ["analgesic", "antipyretic"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Zyrtec",
                generic: "Zyrtec",
                brand: "Zyrtec"
            };
            attributes = {};
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DOSE] = ["10 mg"];
            attributes[visible.ATTR_DRUG_CLASS] = ["antihistamine"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Allegra-D",
                generic: "Allegra-D",
                brand: "Allegra-D"
            };
            attributes = {};
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["BID"];
            attributes[visible.ATTR_DOSE] = ["60 / 120 mg"];
            attributes[visible.ATTR_DRUG_CLASS] = ["antihistamine", "decongestant"];
            attributes[visible.ATTR_SUBITEM] = [
                        {
                            name: "Fexofenadine",
                            attributes: { "__ATTR_DOSAGE__" : ["60 mg"] }
                        },
                        {
                            name: "Pseudoephedrine",
                            attributes: { "__ATTR_DOSAGE__" : ["120 mg"] }
                        }
                    ];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Acetaminophen",
                generic: "Acetaminophen",
                brand: "Acetaminophen"
            };
            attributes = {};
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["q4h"];
            attributes[visible.ATTR_DOSE] = ["325 mg"];
            attributes[visible.ATTR_DRUG_CLASS] = ["analgesic", "antipyretic"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Darbepoetin",
                generic: "Darbepoetin",
                brand: "Darbepoetin"
            };
            attributes = {};
            attributes[visible.ATTR_ROUTE] = ["SC"];
            attributes[visible.ATTR_FREQUENCY] = ["qFriday"];
            attributes[visible.ATTR_DOSE] = ["60 mg"];
            attributes[visible.ATTR_DRUG_CLASS] = ["ESA"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Sudafed",
                generic: "Sudafed",
                brand: "Sudafed"
            };
            attributes = {};
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["q6h"];
            attributes[visible.ATTR_DOSE] = ["30 mg"];
            attributes[visible.ATTR_DRUG_CLASS] = ["decongestant"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
    
    
            name = {
                recorded: "Aspirin",
                generic: "Aspirin",
                brand: "Aspirin"
            };
            attributes = {};
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DOSE] = ["81 mg"];
            attributes[visible.ATTR_DRUG_CLASS] = ["salicylate"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Claritin",
                generic: "Claritin",
                brand: "Claritin"
            };
            attributes = {};
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DOSE] = ["10 mg"];
            attributes[visible.ATTR_DRUG_CLASS] = ["antihistamine"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Advil",
                generic: "Advil",
                brand: "Advil"
            };
            attributes = {};
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["q4h"];
            attributes[visible.ATTR_DOSE] = ["200 mg"];
            attributes[visible.ATTR_DRUG_CLASS] = ["NSAID"];
            
            item = new ListItem(i, visible.list1.id, name, attributes);
            visible.list1.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            // populate list 2
            name = {
                recorded: "Fexofenadine",
                generic: "Fexofenadine",
                brand: "Fexofenadine"
            };
            attributes = {};
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DOSE] = ["60 mg"];
            attributes[visible.ATTR_DRUG_CLASS] = ["antihistamine"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Acetaminophen",
                generic: "Acetaminophen",
                brand: "Acetaminophen"
            };
            attributes = {};
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["q4h"];
            attributes[visible.ATTR_DOSE] = ["3325 mg"];
            attributes[visible.ATTR_DRUG_CLASS] = ["analgesic", "antipyretic"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Ibuprofen",
                generic: "Ibuprofen",
                brand: "Ibuprofen"
            };
            attributes = {};
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["q4h"];
            attributes[visible.ATTR_DOSE] = ["200 mg"];
            attributes[visible.ATTR_DRUG_CLASS] = ["NSAID"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Acetaminophen",
                generic: "Acetaminophen",
                brand: "Acetaminophen"
            };
            attributes = {};
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["q4h"];
            attributes[visible.ATTR_DOSE] = ["325 mg"];
            attributes[visible.ATTR_DRUG_CLASS] = ["analgesic", "antipyretic"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Prednisone",
                generic: "Prednisone",
                brand: "Prednisone"
            };
            attributes = {};
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["daily"];
            attributes[visible.ATTR_DOSE] = ["30 mg"];
            attributes[visible.ATTR_DRUG_CLASS] = ["corticosteroid"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Acetaminophen",
                generic: "Acetaminophen",
                brand: "Acetaminophen"
            };
            attributes = {};
            attributes[visible.ATTR_ROUTE] = ["PO"];
            attributes[visible.ATTR_FREQUENCY] = ["q6h"];
            attributes[visible.ATTR_DOSE] = ["325 mg"];
            attributes[visible.ATTR_DRUG_CLASS] = ["analgesic", "antipyretic"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
            
            
            name = {
                recorded: "Darbepoetin",
                generic: "Darbepoetin",
                brand: "Darbepoetin"
            };
            attributes = {};
            attributes[visible.ATTR_ROUTE] = ["SC"];
            attributes[visible.ATTR_FREQUENCY] = ["qFriday"];
            attributes[visible.ATTR_DOSE] = ["60 mg"];
            attributes[visible.ATTR_DRUG_CLASS] = ["ESA"];
            
            item = new ListItem(i, visible.list2.id, name, attributes);
            visible.list2.source.push(item.id);
            visible.items[item.id] = item;
            i++;
        }
        
        
        
        visible.undecided = visible.list1.source
                .concat(visible.list2.source);
        visible.nextID = i;
    }
    
    function populateShadows() {
        // detect all possible groups
        var potentialGroups = {};
        var potentialGroupByAttributes = [];
        
        for (var attribute in visible.attributes) {
            if (visible.attributes[attribute].type ===
                    visible.ATTR_TYPE_CATEGORICAL) {
                potentialGroupByAttributes.push(attribute);
            }
        }
        
        for (var id in visible.items) {
            for (var i = 0; i < potentialGroupByAttributes.length; i++) {
                var attributes = visible.items[id].attributes;
                var attribute = potentialGroupByAttributes[i];
                
                
                if (attribute in attributes) {
                    var values = attributes[attribute];
                    
                    for (var j = 0; j < values.length; j++) {
                        var value = values[j];
                        
                        if (potentialGroups[value] === undefined) {
                            potentialGroups[value] = [];
                        }
                        potentialGroups[value].push(id);
                    }
                }
            }
        }
        
        // slight optimization: remove 1-item groups when multigrouping
        for (var groupByAttribute in potentialGroups) {
            if (potentialGroups[groupByAttribute].length < 2) {
                delete potentialGroups[groupByAttribute];
            }
        }
        
        // create shadows
        for (var id in visible.items) {
            var item = visible.items[id];
            
            // originals will always be associated with the primary group
            item.groupByOffset = 0;
            
            // originals are not shadows, and currently have no shadows
            item.isShadow = false;
            item.isShadowed = false;
            
            // search for potential shadows
            for (var attributeName in visible.attributes) {
                var attribute = visible.attributes[attributeName];
                
                if (attribute.type === visible.ATTR_TYPE_CATEGORICAL) {
                    if (attributeName in item.attributes) {
                        var values = item.attributes[attributeName];
                        
                        if (values.length > 1) {
                            /*
                             * Prepare shadows; these "shadows" will only appear
                             * when the user groups by this particular
                             * attribute.
                             * 
                             * For group affiliation [ A, B, C ]:
                             *   - the original will be grouped with A,
                             *   - shadow 0 will be grouped with B, and
                             *   - shadow 1 will be grouped with C.
                             * 
                             * Acting on the original will act on all shadows;
                             * acting on a shadow will similarly act on the
                             * original (and all other shadows).
                             */
                            for (var i = 1; i < values.length; i++) {
                                var value = values[i];
                                
                                // don't create unnecessary shadows
                                if (potentialGroups[value] === undefined) {
                                    continue;
                                }
                                
                                // convention: originalID_shadowID
                                var shadowID = id + "_" + (i - 1);
                                
                                // create the shadow from the original
                                var shadow = new ListItem(shadowID,
                                    item.listID, item.getNames(),
                                    item.attributes);
                                shadow.isShadow = true;
                                shadow.isShadowed = false;
                                shadow.groupByOffset = i;
                                
                                visible.shadows[shadowID] = shadow;
                                
                                // original now has a shadow
                                item.isShadowed = true;
                                
                                // for convenience, hash in items as well
                                visible.items[shadowID] = shadow;
                                        
                                // hash from original to shadow
                                if (id in visible.itemsToShadows) {
                                    visible.itemsToShadows[id].push(shadowID);
                                } else {
                                    visible.itemsToShadows[id] = [shadowID];
                                }
                                
                                // hash from shadow to original
                                visible.shadowsToItems[shadowID] = id;
                            }
                        }
                    }
                }
            }
        }
    }
    
    function detectAttributes() {
        visible.attributes[visible.ATTR_NAME] = {
                    type : visible.ATTR_TYPE_GENERAL,
                    display : true
                };
        visible.attributes[visible.ATTR_DOSE] = {
                    type : visible.ATTR_TYPE_NUMERIC,
                    display : true
                };
        visible.attributes[visible.ATTR_ROUTE] = {
                    type : visible.ATTR_TYPE_CATEGORICAL,
                    display : true,
                    rank : []
                };
        visible.attributes[visible.ATTR_FREQUENCY] = {
                    type : visible.ATTR_TYPE_GENERAL,
                    display : true
                };
        visible.attributes[visible.ATTR_DRUG_CLASS] = {
                    type : visible.ATTR_TYPE_CATEGORICAL,
                    display : false,
                    rank : [
                        "antipyretic",
                        "antibiotic",
                        "analgesic",
                        "antidiabetic",
                        "sedative",
                        "antianxiety",
                        "diuretic",
                        "bronchodilator",
                        "corticosteroid",
                        "antipsychotic",
                        "antihypertensive",
                        "anticoagulant",
                        "antihistamine",
                        "thyroid",
                        "antiplatelet",
                        "non-steroidal anti-inflammatory drug",
                        "antacid",
                        "antidepressant",
                        "acetylcholinesterase inhibitor",
                        "antismoking",
                        "sex hormone",
                        "anticholesterol",
                        "bone resorption inhibitor",
                        "dietary supplement",
                        "laxative",
                        "stool softener",
                        "unknown"
                    ]
                };
        visible.attributes[visible.ATTR_SUBITEM] = {
                    type : visible.ATTR_TYPE_GENERAL,
                    display : false
                };
        visible.attributes[visible.ATTR_INSTRUCTIONS] = {
                    type : visible.ATTR_TYPE_GENERAL,
                    display : false
                };
    }
    
    function detectRelationships(dataset) {
        var i, identical, similar;
        
        if (dataset === visible.DATASET_APP) {
            visible.unique1 = [0, 5];
            visible.unique2 = [9, 10];
            
            identical = [
                [1, 11],
                [4, 8]
            ];
            
            similar = [
                    {
                        items: [2, 7],
                        differences: [visible.ATTR_NAME,
                                visible.ATTR_DOSE]
                    },
                    {
                        items: [3, 6],
                        differences: [visible.ATTR_NAME]
                    }];
        } else if (dataset === visible.DATASET_CHF1) {
            visible.unique1 = [3, 8];
            visible.unique2 = [16, 18, 20];
            
            identical = [
                [5, 12],
                [7, 13]
            ];
            
            similar = [
                    {
                        items: [0, 11],
                        differences: [visible.ATTR_FREQUENCY]
                    },
                    {
                        items: [1, 22],
                        differences: [visible.ATTR_NAME,
                                visible.ATTR_FREQUENCY]
                    },
                    {
                        items: [2, 17],
                        differences: [visible.ATTR_NAME,
                                visible.ATTR_FREQUENCY]
                    },
                    {
                        items: [4, 15],
                        differences: [visible.ATTR_NAME,
                                visible.ATTR_FREQUENCY]
                    },
                    {
                        items: [6, 14],
                        differences: [visible.ATTR_FREQUENCY]
                    },
                    {
                        items: [9, 21],
                        differences: [visible.ATTR_NAME,
                                visible.ATTR_FREQUENCY]
                    },
                    {
                        items: [10, 19],
                        differences: [visible.ATTR_NAME,
                                visible.ATTR_DOSE,
                                visible.ATTR_FREQUENCY]
                    }];
        } else if (dataset === visible.DATASET_CHF2) {
            visible.unique1 = [5, 6, 8];
            visible.unique2 = [14, 21];
            
            identical = [
                [7, 15],
                [9, 16]
            ];
            
            similar = [
                    {
                        items: [0, 11],
                        differences: [visible.ATTR_NAME]
                    },
                    {
                        items: [1, 12],
                        differences: [visible.ATTR_NAME,
                                visible.ATTR_DOSE]
                    },
                    {
                        items: [2, 13],
                        differences: [visible.ATTR_NAME,
                                visible.ATTR_DOSE]
                    },
                    {
                        items: [3, 18],
                        differences: [visible.ATTR_NAME,
                                visible.ATTR_FREQUENCY]
                    },
                    {
                        items: [4, 19, 20],
                        differences: [visible.ATTR_NAME,
                                visible.ATTR_DOSE, visible.ATTR_FREQUENCY]
                    },
                    {
                        items: [10, 17],
                        differences: [visible.ATTR_FREQUENCY]
                    }];
        } else if (dataset === visible.DATASET_PD1) {
            visible.unique1 = [0, 2, 5, 6, 10, 11, 12, 14];
            visible.unique2 = [16, 19, 22, 23, 25, 27];
            
            identical = [
                [3, 26],
                [15, 18]
            ];
            
            similar = [
                    {
                        items: [1, 28],
                        differences: [visible.ATTR_NAME]
                    },
                    {
                        items: [4, 13, 17],
                        differences: [visible.ATTR_NAME,
                                visible.ATTR_DOSE, visible.ATTR_FREQUENCY]
                    },
                    {
                        items: [7, 20],
                        differences: [visible.ATTR_NAME,
                                visible.ATTR_FREQUENCY]
                    },
                    {
                        items: [8, 24],
                        differences: [visible.ATTR_DOSE]
                    },
                    {
                        items: [9, 21],
                        differences: [visible.ATTR_NAME,
                                visible.ATTR_FREQUENCY]
                    }];
        } else if (dataset === visible.DATASET_PD2) {
            visible.unique1 = [0, 2, 3, 10, 11, 12, 15];
            visible.unique2 = [16, 18, 19, 20, 29];
            
            identical = [
                [5, 22],
                [6, 23],
                [13, 27]
            ];
            
            similar = [
                    {
                        items: [1, 17],
                        differences: [visible.ATTR_NAME,
                                visible.ATTR_DOSE, visible.ATTR_FREQUENCY]
                    },
                    {
                        items: [4, 21],
                        differences: [visible.ATTR_NAME,
                                visible.ATTR_DOSE, visible.ATTR_FREQUENCY]
                    },
                    {
                        items: [7, 24],
                        differences: [visible.ATTR_NAME]
                    },
                    {
                        items: [8, 25],
                        differences: [visible.ATTR_NAME,
                                visible.ATTR_FREQUENCY]
                    },
                    {
                        items: [9, 26],
                        differences: [visible.ATTR_NAME]
                    },
                    {
                        items: [14, 28],
                        differences: [visible.ATTR_NAME]
                    }
                    ];
        } else if (dataset === visible.DATASET_OTHER_SIMPLE) {
            visible.unique1 = [4];
            visible.unique2 = [9, 10, 13];
            
            identical = [
                    [1, 7],
                    [2, 12],
                    [3, 11]
                    ];
            
            similar = [
                    {
                        items: [0, 6],
                        differences: [visible.ATTR_FREQUENCY,
                                visible.ATTR_DOSAGAE]
                    },
                    {
                        items: [5, 8],
                        differences: [visible.ATTR_NAME]
                    }
            		];
        } else if (dataset === visible.DATASET_OTHER_COMPLEX) {
        	    visible.unique2 = [14];
            visible.unique1 = [2, 7, 8];
            
            identical = [
                    [0, 4, 13],
                    [5, 16]
                    ];
            
            similar = [
                    {
                        items: [0, 1, 4, 11, 13, 15],
                        differences: [visible.ATTR_NAME,
                                visible.ATTR_FREQUENCY, visible.ATTR_DOSAGE]
                    },
                    {
                        items: [3, 6, 10],
                        differences: [visible.ATTR_NAME,
                                visible.ATTR_FREQUENCY, visible.ATTR_DOSAGE]
                    },
                    {
                        items: [9, 12],
                        differences: [visible.ATTR_NAME]
                    }
                    ];
        }
                
        if (identical || similar) {
        	
            for (var i = 0; i < identical.length; i++) {
                var set = identical[i];
                
                for (var j = 0; j < set.length; j++) {
                    visible.identical[set[j]] = set;
                }
            }
            
            for (var i = 0; i < similar.length; i++) {
                set = similar[i];
                
                for (var j = 0; j < set.items.length; j++) {
                    visible.similar[set.items[j]] = set;
                }
            }
        }
    }
    
    
    // sort
    function groupThenSort(a, b) {
        var groupOrder = visible.groupBy ?
                attributeSort(a, b, visible.groupBy,
                visible.attributes[visible.groupBy].rank) : 0;
        
        if (groupOrder === 0) {
            var sortOrder = visible.sortBy ?
                    attributeSort(a, b, visible.sortBy) :
                    visible.items[a].id - visible.items[b].id;
                    
            if (visible.sortBy && sortOrder === 0) {
                return visible.items[a].id - visible.items[b].id;
            }
            return sortOrder;
        }
        return groupOrder;
    }
    
    function attributeSort(a, b, attribute, rank) {
        var itemA = visible.items[a];
        var itemB = visible.items[b];
        var attributeA, attributeB;
        
        if (attribute === visible.ATTR_NAME) {      // case-insensitive
            attributeA = itemA.name.toLowerCase();
            attributeB = itemB.name.toLowerCase();
        } else {
            attributeA = itemA.attributes[attribute][
                    (visible.multigroup ? itemA.groupByOffset : 0)];
            attributeB = itemB.attributes[attribute][
                    (visible.multigroup ? itemB.groupByOffset : 0)];
        }
        
        if (visible.attributes[attribute].type ===
                visible.ATTR_TYPE_NUMERIC) {
            attributeA = parseFloat(attributeA);
            attributeB = parseFloat(attributeB);
        }
        
        if (rank) {
            var rankA = rank.indexOf(attributeA);
            var rankB = rank.indexOf(attributeB);
            
            if (rankA < rankB) {
                return -1;
            } else if (rankA > rankB) {
                return 1;
            }
            // if ranks equal, default to alphanumeric order (below)
        }
        
        if (attributeA < attributeB) {
            return -1;
        } else if (attributeA > attributeB) {
            return 1;
        } else {
            return 0;
        }
    }
    
    
    // filter
    function actionFilter(element, index, array) {
        var $item = $("#" + element);
        
        if (visible.afterAction === visible.AFTER_ACTION_REMOVE &&
                !$item.hasClass("undecided")) {
            return false;
        }
        return true;
    }
    
    function nameFilter(element, index, array) {
        var $item = $("#" + element);
        
        if (visible.filterOn.length > 0 &&
                visible.items[element].name.toLowerCase()
                .indexOf(visible.filterOn.toLowerCase()) === -1) {
            return false;
        }
        return true;
    }
    
    function unifiedFilter(element, index, array) {
        var keep = actionFilter(element, index, array);
        
        if (keep) {
            keep = nameFilter(element, index, array);
        }
        controller.toggleItem($("#" + element), keep ?
                controller.toggleOnDelay * visible.FILTER_DELAY_SCALE :
                controller.toggleOffDelay / visible.FILTER_DELAY_SCALE,
                keep);
        return keep;
    }
    
    
    // expose interface //////////////////////////////////////////////////
    return visible;
}(window.model = window.model || {}, $, undefined);


// helper object /////////////////////////////////////////////////////////
function ListItem(id, listID, name, attributes) {
    var visible = {};
    var name = name;
    
    visible.id = id;
    visible.listID = listID;
    visible.__defineGetter__("name", function() {
        return name[model.displayName ? model.displayName : "recorded"];
    });
    visible.attributes = attributes;

    visible.getNames = function() {
        return name;
    };
    visible.setName = function(value) {
        name = value;
    };

	visible.isModified = false;
	    
    return visible;
}
